@@ -110,7 +110,13 @@ func (f *finder) Find(opts FindOptions) (*api.PullRequest, ghrepo.Interface, err
 			f.branchName = branch
 		}
 	} else if f.prNumber == 0 {
-		if prNumber, err := strconv.Atoi(strings.TrimPrefix(opts.Selector, "#")); err == nil {
+		// If opts.Selector is a valid number then assume it is the
+		// PR number unless opts.BaseBranch is specified. This is a
+		// special case for PR create command which will always want
+		// to assume that a numerical selector is a branch name rather
+		// than PR number.
+		prNumber, err := strconv.Atoi(strings.TrimPrefix(opts.Selector, "#"))
+		if opts.BaseBranch == "" && err == nil {
 			f.prNumber = prNumber
 		} else {
 			f.branchName = opts.Selector
@@ -272,6 +278,9 @@ func findForBranch(httpClient *http.Client, repo ghrepo.Interface, baseBranch, h
 			PullRequests struct {
 				Nodes []api.PullRequest
 			}
+			DefaultBranchRef struct {
+				Name string
+			}
 		}
 	}
 
@@ -286,6 +295,7 @@ func findForBranch(httpClient *http.Client, repo ghrepo.Interface, baseBranch, h
 			pullRequests(headRefName: $headRefName, states: $states, first: 30, orderBy: { field: CREATED_AT, direction: DESC }) {
 				nodes {%s}
 			}
+			defaultBranchRef { name }
 		}
 	}`, api.PullRequestGraphQL(fieldSet.ToSlice()))
 
@@ -314,7 +324,7 @@ func findForBranch(httpClient *http.Client, repo ghrepo.Interface, baseBranch, h
 	})
 
 	for _, pr := range prs {
-		if pr.HeadLabel() == headBranch && (baseBranch == "" || pr.BaseRefName == baseBranch) {
+		if pr.HeadLabel() == headBranch && (baseBranch == "" || pr.BaseRefName == baseBranch) && (pr.State == "OPEN" || resp.Repository.DefaultBranchRef.Name != headBranch) {
 			return &pr, nil
 		}
 	}
