@@ -118,17 +118,14 @@ func listRun(opts *ListOptions) error {
 		return opts.Exporter.Write(opts.IO, runs)
 	}
 
+	if len(runs) == 0 {
+		return cmdutil.NewNoResultsError("no runs found")
+	}
+
 	tp := utils.NewTablePrinter(opts.IO)
 
 	cs := opts.IO.ColorScheme()
 
-	if len(runs) == 0 {
-		if !opts.PlainOutput {
-			fmt.Fprintln(opts.IO.ErrOut, "No runs found")
-		}
-		return nil
-	}
-
 	out := opts.IO.Out
 
 	if !opts.PlainOutput {
